# Fleurs Dataset

[![PyPI version](https://img.shields.io/pypi/v/fleurs-ds.svg)](https://pypi.org/project/fleurs-ds/)
[![Python Version](https://img.shields.io/pypi/pyversions/fleurs-ds.svg)](https://pypi.org/project/fleurs-ds/)
[![License](https://img.shields.io/pypi/l/fleurs-ds.svg)](https://opensource.org/licenses/MIT)

Google Fleurs As Huggingface Dataset

## Features

## Installation

## Quick Start

### Basic Usage

## Configuration

## License

MIT License
